#!/usr/bin/env python
# tools_da.py

"""
Author : peters 

Revision History:
File created on 03 Oct 2008.

Temporary module to hold classes and methods that are in development

"""

import logging
import os
import shutil
import datetime

def validate_rc(rcfile, needed_items):
    """ validate the contents of an rc-file given a dictionary of required keys """

    for k, v in rcfile.iteritems():
        if v == 'True' :
            rcfile[k] = True
        if v == 'False':
            rcfile[k] = False
        if 'date' in k: 
            rcfile[k] = datetime.datetime.strptime(v, '%Y-%m-%d %H:%M:%S')

    for key in needed_items:
        if not rcfile.has_key(key):
            msg = 'Missing a required value in rc-file : %s' % key
            logging.error(msg)
            raise IOError, msg
    logging.debug('rc-file has been validated succesfully')  


def create_dirs(dirname, forceclean=False):
    """ Create a directory and report success, only if non-existent """

    if forceclean:
        try:
            shutil.rmtree(dirname)
        except:
            pass

    if not os.path.exists(dirname):
        os.makedirs(dirname)
        msg = 'Creating new directory %s' % dirname
        logging.info(msg)
    else:
        msg = 'Using existing directory %s' % dirname
        logging.debug(msg)
    return dirname


def advance_time(time_in, interval):
    """ Advance time_in by a specified interval"""

    time_out = time_in

    if interval == 'month':                       # if monthly, this run will go to the first day of the next month
        if time_in.month != 12: 
            time_out = datetime.datetime(time_in.year, time_in.month + 1, 1, time_in.hour, 0, 0)
        else: 
            time_out = datetime.datetime(time_in.year + 1, 1, 1, time_in.hour, 0, 0)  # end of year provision
    elif interval == 'week':
        time_out = time_in + datetime.timedelta(days=7)
    elif isinstance(interval, datetime.timedelta):
        time_out = time_in + interval
    else:                    # assume that the interval specified is the number of days to run forward before resubmitting
        time_out = time_in + datetime.timedelta(days=float(interval))

    return time_out



def to_datetime(datestring, fmt=None):
    """ convert a date string to a datetime object """
  
    if fmt == 'TM5':
        datestring = '%04s-%02s-%02s %02s:%02s:00' % (datestring[0:4], datestring[4:6], datestring[6:8], datestring[8:10], datestring[10:12])
    elif fmt == 'pycasso-TM5':
        pass # Format already compatible
    else:
        pass 

    try:
        return datetime.datetime.strptime(datestring, '%Y-%m-%d %H:%M:%S')
    except:
        date, time = datestring.split(' ')
        year, month, day = map(int, date.split('-'))
        hour, minute, second = map(int, time.split(':'))
        return datetime.datetime(year, month, day, hour, minute, second)


def name_convert(name=None, to=None):
    """ Convert between old GLOBALVIEW-style and new ObsPack-style

      print name_convert(name="lef_surface-pfp_1", to='GV' )
            lef_01P0

      print name_convert(name="hun_35C3", to='OP' )
            hun_tower-insitu_35
   """

    import re

    identifier = 'name_convert'

    if name == None or to == None: 
        return ""
    
    platform_dict = { 'surface':0, 'shipboard':1, 'aircraft':2, 'tower':3 }
    strategy_dict = { 'flask':'D', 'pfp':'P', 'insitu':'C' }

    #----------------------------------->>>
    if to.upper() == "GV":
        # alt_surface-flask_1 -> alt_01D0
        try:
            fields = name.split('_')
            code = fields[0]
            lab_num = int(fields[2])
        except:
            return ""

        try:
            fields = fields[1].split('-')
            platform = fields[0]
            strategy = fields[1]
        except:
            return ""

        platform_num = [ v for k, v in platform_dict.iteritems() if platform.lower() == k ]
        if len(platform_num) == 0:
            print '%s: Platform %s not found in platform dict.' % (identifier, platform)
            return ""

        strategy_char = [ v for k, v in strategy_dict.iteritems() if strategy.lower() == k ]
        if len(strategy_char) == 0:
            print '%s: Strategy %s not found in strategy dict.' % (identifier, strategy)
            return "" 
        return "%s_%2.2d%1s%1d" % (code, lab_num, strategy_char[0].upper(), int(platform_num[0]))

    #----------------------------------->>>
    if to.upper() == "OP":

        # hun_35C3 -> hun_tower-insitu_35
        try:
            fields = name.split('_')
  
            code = fields[0]
            lab_num = int(fields[1][:2])
            strategy_char = fields[1][2]
            platform_num = int(fields[1][3])
        except:
            return ""

        platform = [ k for k, v in platform_dict.iteritems() if v == platform_num ]
        if len(platform) == 0:
            print '%s: Platform number %s not found in platform dict.' % (identifier, platform_num)
            return ""
        
        pattern = re.compile(strategy_char, re.IGNORECASE)
        strategy = [ k for k, v in strategy_dict.iteritems() if pattern.search(v) ]
        if len(strategy) == 0:
            print '%s: Strategy character %s not found in strategy list.' % (identifier, strategy_char)
            return ""
        return "%s_%s-%s_%d" % (code, platform[0], strategy[0], lab_num)

if __name__ == "__main__":
    pass
